package com.philippeadjiman.rtseproto;

import java.util.List;

import com.google.common.collect.Multiset.Entry;
import com.philippeadjiman.rtseproto.twitter.EnrichedTweet;
import com.philippeadjiman.rtseproto.twitter.Twitter4jSearch;
import com.philippeadjiman.rtseproto.twitter.TwitterRanker;
import com.philippeadjiman.rtseproto.twitter.TwitterSearch;
import com.philippeadjiman.rtseproto.util.URLToolsNaiveImpl;

public class RealTimeSEPrototype {
	public static final int MAX_RESULTS_TO_PRINT = 20;
	
	public static void main(String[] args) {
		if( args.length != 3 ){
			usageAndExit();
		}

		/* checking input query */
		String inputQuery = args[0];
		if(inputQuery.equals("")){
			System.out.println("[ERROR: Input query is empty]");
			usageAndExit();
		}

		/* check and initialize max number of tweets */
		int maxNumberOfTweet = 0;
		try{
			maxNumberOfTweet = Integer.parseInt(args[1]);
			if( maxNumberOfTweet < 0 || maxNumberOfTweet > 1000 ){
				System.out.println("[ERROR: maxNumberOfTweets should be between 1 and 1000]");
				usageAndExit();
			}
		}
		catch(NumberFormatException e){
			System.out.println("[ERROR: "+args[1]+" is an invalid maxNumberOfTweets]");
			usageAndExit();
		}

		/* check and initialize expand mode */
		boolean expandMode = false;
		if( args[2].equalsIgnoreCase("ON") ){
			expandMode = true;
		}
		else if( args[2].equalsIgnoreCase("OFF") ){
			expandMode = false;
		}
		else{
			System.out.println("[ERROR: Expand mode should be either ON or OFF]");
			usageAndExit();
		}

		System.out.println("[INFO: Starting engine...]");
		System.out.println("[INFO: Input Query: "+inputQuery+", Max Number of tweets to use: "+maxNumberOfTweet+", expand mode: "+args[2]+"]");

		/**
		 * Step 1: initialization
		 */
		URLToolsNaiveImpl urlTools = new URLToolsNaiveImpl();
		TwitterSearch twitterSearch = new Twitter4jSearch(urlTools);
		TwitterRanker twitterRanker = new TwitterRanker(urlTools);

		/**
		 * Step 2: retrieving results
		 */
		List<EnrichedTweet> searchResults = twitterSearch.search(inputQuery,maxNumberOfTweet);


		/**
		 * Step 3: ranking results
		 */
		List<Entry<String>> rankURLs = twitterRanker.rankTweetURLs(searchResults,expandMode);

		/**
		 * Step 4: printing results
		 */
		if( searchResults.size() == 0 ){
			System.out.println("No results found for the query "+inputQuery);
		}
		else{
			System.out.println(rankURLs.size()+" results found!");
			if( rankURLs.size() > MAX_RESULTS_TO_PRINT ){
				System.out.println("Printing the first "+MAX_RESULTS_TO_PRINT+" top result(s).");
			}
			int rank = 1;
			for( Entry<String> e : rankURLs ){
				if( rank > MAX_RESULTS_TO_PRINT ){
					break;
				}
				System.out.println("Rank "+rank+" ("+e.getCount()+" hit(s)): "+e.getElement());
				rank++;
			}
		}
	}

	private static void usageAndExit() {
		System.out.println("[Usage: RealTimeSEPrototype \"query\" maxNumberOfTweets expandMode(ON|OFF)]");
		System.exit(0);
	}
}
