package com.philippeadjiman.rtseproto.twitter;

import java.util.ArrayList;
import java.util.List;

import com.philippeadjiman.rtseproto.util.URLTools;

import twitter4j.Query;
import twitter4j.QueryResult;
import twitter4j.Tweet;
import twitter4j.Twitter;
import twitter4j.TwitterException;

/**
 * An implementation of the TwitterSearch interface based on the Twitter4j library
 * @author phil
 *
 */
public class Twitter4jSearch implements TwitterSearch{

	private Twitter twitter = new Twitter();
	
	private URLTools urlTools;

	public Twitter4jSearch(URLTools urlTools){
		this.urlTools = urlTools;
	}

	public List<EnrichedTweet> search(String queryString, int maxNumberOfTweets){
		List<EnrichedTweet> result = new ArrayList<EnrichedTweet>();
		int nbRes  = 0;
		int pageNumber = 1;
		String twitt;
		Query query = new Query(queryString+" filter:links");

		List<Tweet> tweets = getTwitts(twitter, query, pageNumber);
		System.out.println("[INFO: Retrieving tweets (max="+maxNumberOfTweets+") for the query "+queryString+"]");
		System.out.print("0..");
		while( ( tweets.size() > 0 ) && nbRes < maxNumberOfTweets ){
			for (Tweet tweet : tweets ) {
				twitt = tweet.getText();
				List<String> urls = urlTools.extractURLs(twitt);
				nbRes ++;
				result.add(new EnrichedTweet(twitt,urls,tweet.getFromUser()));
				if( nbRes %10 == 0)
					System.out.print(nbRes+"..");
				if( nbRes >= maxNumberOfTweets ){
					break;
				}
			}
			pageNumber++;
			tweets = getTwitts(twitter, query, pageNumber);
		}

		System.out.println(nbRes+" twetts retrieved");
		return result;

	}

	private List<Tweet> getTwitts(Twitter twitter, Query query, int page) {
		QueryResult result;
		query.setPage(page);
		try {
			result = twitter.search(query);
			return result.getTweets();
		} catch (TwitterException e) {
			System.out.println("[ERROR: error from the twitter4j API: "+e+"]");
			return new ArrayList<Tweet>();
		}
	}

	public URLTools getUrlTools() {
		return urlTools;
	}

	public void setUrlTools(URLTools urlTools) {
		this.urlTools = urlTools;
	}

}
