package com.philippeadjiman.rtseproto.twitter;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

import com.google.common.collect.HashMultiset;
import com.google.common.collect.Multiset;
import com.google.common.collect.Multiset.Entry;
import com.philippeadjiman.rtseproto.util.URLTools;

public class TwitterRanker 
{
	private URLTools urlTools;

	public TwitterRanker(URLTools urlTools){
		this.urlTools = urlTools;
	}
	
	public List<Entry<String>> rankTweetURLs(List<EnrichedTweet> tweets, boolean expand){
		if( tweets == null || tweets.size() == 0 ){
			return new ArrayList<Entry<String>>();
		}
		
		Multiset<String> urlsMultiset = HashMultiset.create();

		for( EnrichedTweet tweet : tweets ){
			if( tweet == null || tweet.getUrls() == null || tweet.getUrls().size() == 0 )
				continue;
			for( String s : tweet.getUrls() ){
				urlsMultiset.add(s);
			}
		}

		
		if( expand ){
			int nbRes = 0;
			System.out.println("[INFO: Expanding mode ON]");
			System.out.println("[INFO: Expanding "+urlsMultiset.entrySet().size()+" urls]");
			if( urlsMultiset.entrySet().size() > 50 ){
				System.out.println("[WARNING: It may take a while...]");
			}
			System.out.print("0..");
			Multiset<String> expandedUrlsMultiset = HashMultiset.create();
			for( Entry<String> e : urlsMultiset.entrySet() ){
				String expandedUrl = urlTools.urlExpander(e.getElement());
				expandedUrlsMultiset.add(expandedUrl, e.getCount());
				nbRes++;
				if( nbRes %10 == 0)
					System.out.print(nbRes+"..");
			}
			System.out.println(nbRes+" URL(s) expanded");
			urlsMultiset = expandedUrlsMultiset;
		}


		List<Multiset.Entry<String>> rankedTweetList = new ArrayList<Entry<String>>(urlsMultiset.entrySet());
		Collections.sort(rankedTweetList,occurence_comparator);

		return rankedTweetList;

	}

	/* Should be part of a collection utility class*/
	private static Comparator<Multiset.Entry<String>> occurence_comparator = new Comparator<Multiset.Entry<String>>() {
		public int compare(Multiset.Entry<String> e1, Multiset.Entry<String> e2) {

			int intCompare = e2.getCount() - e1.getCount();
			if( intCompare != 0)
				return intCompare;
			else
				return e1.getElement().compareTo(e2.getElement());
		}
	};

	public URLTools getUrlTools() {
		return urlTools;
	}

	public void setUrlTools(URLTools urlTools) {
		this.urlTools = urlTools;
	}
	
	
	
}
