package com.philippeadjiman.rtseproto;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import com.google.common.collect.Multiset.Entry;
import com.philippeadjiman.rtseproto.twitter.EnrichedTweet;
import com.philippeadjiman.rtseproto.twitter.TwitterRanker;
import com.philippeadjiman.rtseproto.util.URLToolsMock;

import junit.framework.TestCase;

public class TwitterRankerTest extends TestCase {
	public void testRankTweetURLs(){
		//creating some enriched tweets
		List<EnrichedTweet> tweets = new ArrayList<EnrichedTweet>();
		tweets.add(new EnrichedTweet(
				"gitosales @LennyKravitz BRASILIAN SONGS! http://bit.ly/38rMnX http://bit.ly/79WYVg http://tinyurl.com/ydelusf #musicmonday #musician #musicnow #nowplaying", 
				new ArrayList<String>(Arrays.asList("http://bit.ly/38rMnX", "http://bit.ly/79WYVg", "http://tinyurl.com/ydelusf"))
				, "user"));
		
		tweets.add(new EnrichedTweet(
				"http://bit.ly/38rMnX", 
				new ArrayList<String>(Arrays.asList("http://bit.ly/38rMnX"))
				, "user"));
		
		tweets.add(new EnrichedTweet(
				"http://bit.ly/38rMnX", 
				new ArrayList<String>(Arrays.asList("http://bit.ly/38rMnX"))
				, "user"));
		
		tweets.add(new EnrichedTweet(
				"http://bit.ly/79WYVg", 
				new ArrayList<String>(Arrays.asList("http://bit.ly/79WYVg"))
				, "user"));
		
		tweets.add(new EnrichedTweet(
				"http://tinyurl.com/ydelusf", 
				new ArrayList<String>(Arrays.asList("http://tinyurl.com/ydelusf"))
				, "user"));
		tweets.add(new EnrichedTweet(
				"http://emmett-till.blogspot.com", 
				new ArrayList<String>(Arrays.asList("http://emmett-till.blogspot.com"))
				, "user"));
		
		
		/* Test without expanding:
		 * http://bit.ly/38rMnX has 3 occurrences
		 * http://bit.ly/79WYVg has 2 occurrences
		 * http://tinyurl.com/ydelusf has 2 occurrences
		 * http://emmett-till.blogspot.com has 1 occurrence
		 */
		
		TwitterRanker twitterRanker = new TwitterRanker(new URLToolsMock());
		List<Entry<String>> rankTweetURLs = twitterRanker.rankTweetURLs(tweets, false);
		assertEquals(4, rankTweetURLs.size());

		assertEquals(3, rankTweetURLs.get(0).getCount());
		assertEquals("http://bit.ly/38rMnX", rankTweetURLs.get(0).getElement());
		
		assertEquals(2, rankTweetURLs.get(1).getCount());
		assertEquals("http://bit.ly/79WYVg", rankTweetURLs.get(1).getElement());
		
		assertEquals(2, rankTweetURLs.get(2).getCount());
		assertEquals("http://tinyurl.com/ydelusf", rankTweetURLs.get(2).getElement());

		assertEquals(1, rankTweetURLs.get(3).getCount());
		assertEquals("http://emmett-till.blogspot.com", rankTweetURLs.get(3).getElement());
		
		/* Test with expanding:
		 * Since http://bit.ly/79WYVg and http://tinyurl.com/ydelusf points to the same link, we should have:
		 * http://www.youtube.com/watch?v=7SKTy4d3vTU has 4 occurrences
		 * http://www.youtube.com/user/salesmello has 3 occurrences
		 * http://emmett-till.blogspot.com has 1 occurrence
		 */
		rankTweetURLs = twitterRanker.rankTweetURLs(tweets, true);
		assertEquals(3, rankTweetURLs.size());

		assertEquals(4, rankTweetURLs.get(0).getCount());
		assertEquals("http://www.youtube.com/watch?v=7SKTy4d3vTU", rankTweetURLs.get(0).getElement());
		
		assertEquals(3, rankTweetURLs.get(1).getCount());
		assertEquals("http://www.youtube.com/user/salesmello", rankTweetURLs.get(1).getElement());
		
		assertEquals(1, rankTweetURLs.get(2).getCount());
		assertEquals("http://emmett-till.blogspot.com", rankTweetURLs.get(2).getElement());
	}
}
