package com.philippeadjiman.rtseproto;

import java.util.List;

import com.philippeadjiman.rtseproto.util.URLToolsNaiveImpl;

import junit.framework.TestCase;

public class URLToolsNaiveImplTest extends TestCase {
	public void testURLExtractor(){
		URLToolsNaiveImpl urlTools = new URLToolsNaiveImpl();
		//basic case
		String tweet = "Israel's Peres voices hope for Iran govt change: Source: Reuters JERUSALEM, June 21 (Reuters) - Israeli Presiden.. http://bit.ly/seZ1h";
		List<String> urls = urlTools.extractURLs(tweet);
		assertEquals(1,urls.size());
		assertEquals("http://bit.ly/seZ1h",urls.get(0));

		//more than one url
		tweet = "gitosales @LennyKravitz BRASILIAN SONGS! http://bit.ly/38rMnX http://bit.ly/79WYVg http://bit.ly/6Sa4RK #musicmonday #musician #musicnow #nowplaying";
		urls = urlTools.extractURLs(tweet);
		assertEquals(3,urls.size());
		assertEquals("http://bit.ly/38rMnX",urls.get(0));
		assertEquals("http://bit.ly/79WYVg",urls.get(1));
		assertEquals("http://bit.ly/6Sa4RK",urls.get(2));

		//no url
		tweet = "KRice7 Listening to some Bob Marley remixes with Damien and Biggie Smalls...UB40, Busta Rhymes...Tupac. #musicmonday";
		urls = urlTools.extractURLs(tweet);
		assertEquals(0,urls.size());

		//malformed url
		tweet = "texastigress RT @TheBeatlesVideo: The Beatles-Yellow Submarine http:/bit.ly/8R5k2e Plz ReTweet! #musicmonday";
		urls = urlTools.extractURLs(tweet);
		assertEquals(0,urls.size());

		//mixed case
		tweet = "texastigress http://bit.ly/38rMnX RT @TheBeatlesVideo: The Beatles-Yellow Submarine http:/bit.ly/8R5k2e Plz ReTweet! http://bit.ly/6Sa4RK #musicmonday";
		urls = urlTools.extractURLs(tweet);
		assertEquals(2,urls.size());
		assertEquals("http://bit.ly/38rMnX",urls.get(0));
		assertEquals("http://bit.ly/6Sa4RK",urls.get(1));
	}

	public void testURLExpander(){
		URLToolsNaiveImpl urlTools = new URLToolsNaiveImpl();
		String url = "http://bit.ly/38rMnX";
		
		//expanding a short url
		String expand = urlTools.urlExpander(url);
		assertEquals("http://www.youtube.com/user/salesmello",expand);
		
		//expanding a short url
		expand = urlTools.urlExpander("http://tcrn.ch/6c8AU4");
		assertEquals("http://www.techcrunch.com/2010/01/05/techcrunch-giveaway-a-google-nexus-one-techcrunch/",expand);

		
		//expanding a already expanded url
		expand = urlTools.urlExpander(expand);
		assertEquals(expand,expand);
		
		//expanding a malformed url
		url = "http:/bit.ly/38rMnX";
		expand = urlTools.urlExpander(url);
		assertEquals(url,expand);
		
		
		
	}
}
